<?php
/**
 * @package         Articles Anywhere
 * @version         10.3.2PRO
 * 
 * @author          Peter van Westen <info@regularlabs.com>
 * @link            http://www.regularlabs.com
 * @copyright       Copyright © 2020 Regular Labs All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory as JFactory;
use RegularLabs\Library\Document as RL_Document;
use RegularLabs\Library\Html as RL_Html;
use RegularLabs\Library\Plugin as RL_Plugin;
use RegularLabs\Library\Protect as RL_Protect;
use RegularLabs\Plugin\System\ArticlesAnywhere\Params;
use RegularLabs\Plugin\System\ArticlesAnywhere\Protect;
use RegularLabs\Plugin\System\ArticlesAnywhere\Replace;

// Do not instantiate plugin on install pages
// to prevent installation/update breaking because of potential breaking changes
$input = JFactory::getApplication()->input;
if (in_array($input->get('option'), ['com_installer', 'com_regularlabsmanager']) && $input->get('action') != '')
{
	return;
}

if ( ! is_file(__DIR__ . '/vendor/autoload.php'))
{
	return;
}

require_once __DIR__ . '/vendor/autoload.php';

if ( ! is_file(JPATH_LIBRARIES . '/regularlabs/autoload.php'))
{
	JFactory::getLanguage()->load('plg_system_articlesanywhere', __DIR__);
	JFactory::getApplication()->enqueueMessage(
		JText::sprintf('AA_EXTENSION_CAN_NOT_FUNCTION', JText::_('ARTICLESANYWHERE'))
		. ' ' . JText::_('AA_REGULAR_LABS_LIBRARY_NOT_INSTALLED'),
		'error'
	);

	return;
}

require_once JPATH_LIBRARIES . '/regularlabs/autoload.php';

if (true)
{
	class PlgSystemArticlesAnywhere extends RL_Plugin
	{
		public $_lang_prefix           = 'AA';
		public $_has_tags              = true;
		public $_disable_on_components = true;

		/**
		 * @param object  &$subject    The object to observe
		 * @param array    $config     An optional associative array of configuration settings.
		 *                             Recognized key values include 'name', 'group', 'params', 'language'
		 *                             (this list is not meant to be comprehensive).
		 */
		public function __construct(&$subject, $config = [])
		{
			$this->_params = Params::get();

			parent::__construct($subject, $config);
		}

		public function processArticle(&$string, $area = 'article', $context = '', $article = null, $page = 0)
		{
			if ( ! isset($article->id) && isset($article->slug))
			{
				$slug_parts = explode(':', $article->slug);
				$article_id = array_shift($slug_parts);
				if (is_numeric($article_id))
				{
					$article->id = $article_id;
				}
			}

			Replace::replaceTags($string, $area, $context, $article);
		}

		protected function handleOnAfterInitialise()
		{
			// Adds the Articles Anywhere pagination page_param to the url params to ignore in caching
			if ( ! isset(JFactory::getApplication()->registeredurlparams))
			{
				JFactory::getApplication()->registeredurlparams = (object) [];
			}

			$params = Params::get();

			JFactory::getApplication()->registeredurlparams->{$params->page_param} = 'UINT';

			if ( ! empty($params->registeredurlparams))
			{
				foreach ($params->registeredurlparams as $param)
				{
					JFactory::getApplication()->registeredurlparams->{$param->name} = $param->type;
				}
			}
		}

		protected function handleOnAfterDispatch()
		{
			if ( ! $buffer = RL_Document::getBuffer())
			{
				return;
			}

			if ( ! Replace::replaceTags($buffer, 'component'))
			{
				return;
			}

			RL_Document::setBuffer($buffer);
		}

		protected function changeFinalHtmlOutput(&$html)
		{
			if (RL_Document::isFeed())
			{
				Replace::replaceTags($html);

				return true;
			}

			// only do stuff in body
			list($pre, $body, $post) = RL_Html::getBody($html);
			Replace::replaceTags($body, 'body');
			$html = $pre . $body . $post;

			return true;
		}

		protected function cleanFinalHtmlOutput(&$html)
		{
			RL_Protect::removeAreaTags($html, 'ARTA');

			$params = Params::get();

			Protect::unprotectTags($html);

			RL_Protect::removeFromHtmlTagContent($html, Params::getTags(true));
			RL_Protect::removeInlineComments($html, 'Articles Anywhere');

			if ( ! $params->place_comments)
			{
				RL_Protect::removeCommentTags($html, 'Articles Anywhere');
			}
		}
	}
}
